from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="ctt-fe",
    version="1.0.0",
    author="Americo Simoes",
    author_email="amexsimoes@gmail.com",
    description="CTT ctt-fe - Guaranteed stable simulations with α = 0.0302011",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/SimoesCTT/CTT-Engineering-Suite",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: Other/Proprietary License",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Physics",
        "Topic :: Scientific/Engineering :: Mathematics",
    ],
    python_requires=">=3.8",
    install_requires=[
        "numpy>=1.21.0",
        "scipy>=1.7.0",
    ],
)
